package X3D::FieldTypes::MFVec4d;

our $VERSION = '0.009';

use X3D::Package 'MFVec4d : X3DArrayField { [] }';

1;
__END__
